==> haskell-mintty-0.1.1-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.1
id: mintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
key: mintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
license: BSD3
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
author: Ryan Scott
exposed: True
indefinite: False
exposed-modules:
    System.Console.MinTTY
abi: 36889cafffee4f4a6a5881d3153f2325
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/mintty-0.1.1
library-dirs: /usr/lib/ghc-8.2.2/site-local/mintty-0.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/mintty-0.1.1
hs-libraries: HSmintty-0.1.1-5pAMEmpWcFDFkMLqWRTQo7
depends:
    base-4.10.1.0
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mintty-0.1.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-mintty.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: mintty
version: 0.1.2
id: mintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
key: mintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
license: BSD-3-Clause
copyright: (C) 2017 Ryan Scott
maintainer: Ryan Scott <ryan.gl.scott@gmail.com>
author: Ryan Scott
stability: Provisional
homepage: https://github.com/RyanGlScott/mintty
synopsis: A reliable way to detect the presence of a MinTTY console on Windows
description:
    MinTTY is a Windows-specific terminal emulator for the
    widely used Cygwin and MSYS projects, which provide
    Unix-like environments for Windows. MinTTY consoles behave
    differently from native Windows consoles (such as
    @cmd.exe@ or PowerShell) in many ways, and in some cases,
    these differences make it necessary to treat MinTTY
    consoles differently in code.
    .
    The @mintty@ library provides a simple way to detect if
    your code in running in a MinTTY console on Windows. It
    exports @isMinTTY@, which does the right thing 90% of the
    time (by checking if standard error is attached to
    MinTTY), and it also exports @isMinTTYHandle@ for the
    other 10% of the time (when you want to check is some
    arbitrary handle is attached to MinTTY). As you might
    expect, both of these functions will simply return @False@
    on any non-Windows operating system.
category: System
abi: 682b79297bf0df6d17e983defbb512c6
exposed: True
exposed-modules:
    System.Console.MinTTY
import-dirs: /usr/lib/ghc-8.4.2/site-local/mintty-0.1.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/mintty-0.1.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/mintty-0.1.2
hs-libraries: HSmintty-0.1.2-JbzlJTT95QQ6PkuXy4kGuG
depends:
    base-4.11.1.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
haddock-interfaces: /usr/share/doc/haskell-mintty/html/mintty.haddock
haddock-html: /usr/share/doc/haskell-mintty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
